package com.yingji.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yingji.entity.AcceptEvents;
import com.yingji.entity.Amb;
import com.yingji.entity.Event;
import com.yingji.entity.Task;
import com.yingji.entity.dto.response.EventPageRequest;
import com.yingji.entity.dto.response.EventsFindResponse;
import com.yingji.exception.ServiceException;
import com.yingji.mapper.EventMapper;
import com.yingji.service.AcceptService;
import com.yingji.service.AmbService;
import com.yingji.service.EventService;
import com.yingji.service.TaskService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 事故(Event)表服务实现类
 *
 * @author wu
 * @since 2024-05-10 17:10:33
 */
@Service("eventService")
@Slf4j
public class EventServiceImpl extends ServiceImpl<EventMapper, Event> implements EventService {

    @Resource
    private TaskService taskService;

    @Resource
    private AmbService ambService;

    @Resource
    private AcceptService acceptService;

    /**
     * 分页条件查询数据
     *
     * @param page  分页条件
     * @param event 查询条件
     * @return 数据
     */
    @Override
    public Page<Event> page(Page<Event> page, EventPageRequest event) {
        log.error("==================119入参开始=====================");
        log.error("==================119每页显示条数: " + page.getSize() + "页数: " + page.getCurrent() + "=====================");
        log.error(JSONUtil.toJsonStr(event));
        log.error("==================119入参结束=====================");
        QueryWrapper<Event> wrapper = new QueryWrapper<>();
        wrapper.ne("event_type", "转院")
                .like(StrUtil.isNotEmpty(event.getEventName()), "event_name", event.getEventName())
                .eq(StrUtil.isNotEmpty(event.getEventType()), "event_type", event.getEventType())
                .eq(StrUtil.isNotEmpty(event.getEventLevel()), "event_level", event.getEventLevel())
                .ge(event.getStartTime() != null, "create_time", event.getStartTime())
                .le(event.getEndTime() != null, "create_time", event.getEndTime())
                .like(StrUtil.isNotEmpty(event.getEventArea()), "event_area", event.getEventArea())
                .like(StrUtil.isNotEmpty(event.getEventAddress()), "event_address", event.getEventAddress())
                .eq(event.getSendAmbCount() != null, "send_amb_count", event.getSendAmbCount())
                .like(StrUtil.isNotEmpty(event.getEventDescribe()), "event_describe", event.getEventDescribe())
                .like(StrUtil.isNotEmpty(event.getAlarmUnit()), "alarm_unit", event.getAlarmUnit())
                .like(StrUtil.isNotEmpty(event.getAlarmUnitContactor()), "alarm_unit_contactor", event.getAlarmUnitContactor())
                .like(StrUtil.isNotEmpty(event.getAlarmUnitTelephone()), "alarm_unit_telephone", event.getAlarmUnitTelephone());
        log.error("==================119响应开始=====================");
        log.error("==================119响应结束=====================");
        return this.page(page, wrapper);
    }

    /**
     * 根据id查询数据
     *
     * @param id id
     * @return 数据
     */
    @Override
    public EventsFindResponse findById(Serializable id) {
        Event event = this.getById(id);
        if (BeanUtil.isEmpty(event)) {
            throw new ServiceException("所选数据不存在");
        }
        EventsFindResponse res = BeanUtil.copyProperties(event, EventsFindResponse.class);
        // 查询任务信息
        QueryWrapper<Task> taskWrapper = new QueryWrapper<>();
        taskWrapper.eq("event_id", res.getEventId());
        List<Task> taskList = taskService.list(taskWrapper);
        // 受理调度信息
        QueryWrapper<AcceptEvents> acceptWrapper = new QueryWrapper<>();
        acceptWrapper.eq("event_id", res.getEventId());
        List<AcceptEvents> acceptList = acceptService.list(acceptWrapper);
        // 任务车辆
        List<String> taskIdList = taskList.stream().map(Task::getTaskId).collect(Collectors.toList());
        if (CollUtil.isNotEmpty(taskIdList)) {
            QueryWrapper<Amb> ambWrapper = new QueryWrapper<>();
            ambWrapper.in("task_id", taskIdList);
            List<Amb> ambList = ambService.list(ambWrapper);
            res.setAmbs(ambList);
        }
        res.setAcceptEvents(acceptList);
        res.setTasks(taskList);
        return res;
    }


}

